@@ -1,4 +1,4 @@
-﻿(function () {
+﻿define(['jQuery'], function ($) {
 
     var supportsTextTracks;
     var hlsPlayer;
@@ -512,7 +512,8 @@
 
         function enableNativeTrackSupport(track) {
 
-            if (browserInfo.safari) {
+            if (browserInfo.safari && browserInfo.mobile) {
+                // Leave it to apple to have different behavior between safari on ios vs osx
                 return false;
             }
 
@@ -594,13 +595,13 @@
                 trackElement.label = 'manualTrack' + track.index;
 
                 // download the track json
-                fetchSubtitles(track).then(function(data) {
+                fetchSubtitles(track).then(function (data) {
 
                     // show in ui
                     console.log('downloaded ' + data.TrackEvents.length + ' track events');
                     // add some cues to show the text
                     // in safari, the cues need to be added before setting the track mode to showing
-                    data.TrackEvents.forEach(function(trackEvent) {
+                    data.TrackEvents.forEach(function (trackEvent) {
                         trackElement.addCue(new VTTCue(trackEvent.StartPositionTicks / 10000000, trackEvent.EndPositionTicks / 10000000, trackEvent.Text.replace(/\\N/gi, '\n')));
                     });
                     trackElement.mode = 'showing';
@@ -645,7 +646,7 @@
                 console.log('expectedId: ' + expectedId + '--currentTrack.Id:' + currentTrack.id);
 
                 // IE doesn't support track id
-                if (browserInfo.msie) {
+                if (browserInfo.msie || browserInfo.edge) {
                     if (trackIndex == i) {
                         mode = 1; // show this track
                     } else {
@@ -780,4 +781,4 @@
         };
     }
 
-})();
\ No newline at end of file
+});
\ No newline at end of file
